# Create Mountaineer App

Create Mountaineer App 🏔️ (CMA for short) is a utility that makes it easily to get started on a new Mountaineer project. It provides all the scaffolding files and best practices that you'll need to hit the ground running.

Make sure you have pipx [installed](https://pipx.pypa.io/stable/installation/).

```bash
$ pipx run create-mountaineer-app

? Project name [my-project]: my_webapp
? Author [Pierce Freeman <pierce@freeman.vc>] Default
? Use poetry for dependency management? [Yes] Yes
? Create stub MVC files? [Yes] Yes
? Use Tailwind CSS? [Yes] Yes
? Add editor configuration? [vscode] vscode
```

For more details on what files were just created and how to use them, continue to the [Structure](structure.md) page.
